@@ -9,8 +9,8 @@ class Result(object):
         self.data = data
 
     @classmethod
-    def ok(cls):
-        return Result(Error.OK, 'success')
+    def ok(cls, data=None):
+        return Result(Error.OK, 'success').set_data(data)
 
     @classmethod
     def error(cls, base_error = None):
